//+------------------------------------------------------------------+
//|                                          consecutive candles.mq4 |
//+------------------------------------------------------------------+
#property link      "https://www.forexfactory.com/icerice"
#property version   "1.03"
#property strict
#property indicator_chart_window
#property indicator_buffers 4
#property indicator_plots   4
//--- plot BuySignal
#property indicator_label1  "BuySignal"
#property indicator_type1   DRAW_ARROW
#property indicator_color1  clrLimeGreen
#property indicator_style1  STYLE_SOLID
#property indicator_width1  1
//--- plot SellSignal
#property indicator_label2  "SellSignal"
#property indicator_type2   DRAW_ARROW
#property indicator_color2  clrRed
#property indicator_style2  STYLE_SOLID
#property indicator_width2  1
//--- plot BuyDot
#property indicator_label3  "BuyDotSignal"
#property indicator_type3   DRAW_ARROW
#property indicator_color3  clrLimeGreen
#property indicator_style3  STYLE_SOLID
#property indicator_width3  1
//--- plot SellDot
#property indicator_label4  "SellDotSignal"
#property indicator_type4   DRAW_ARROW
#property indicator_color4  clrRed
#property indicator_style4  STYLE_SOLID
#property indicator_width4  1


//--- input parameters
input bool     ShowAlert=true;
input bool     ShowArrows=true;
input bool     ShowDots=true;

//--- indicator buffers
double         BuySignalBuffer[];
double         SellSignalBuffer[];
double         BuyDotBuffer[];
double         SellDotBuffer[];

datetime LastAlertTime;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- indicator buffers mapping
   SetIndexBuffer(0,BuySignalBuffer);
   SetIndexBuffer(1,SellSignalBuffer);
   SetIndexBuffer(2,BuyDotBuffer);
   SetIndexBuffer(3,SellDotBuffer);
//--- setting a code from the Wingdings charset as the property of PLOT_ARROW
   SetIndexArrow(0,233);
   SetIndexArrow(1,234);
   SetIndexArrow(2,159);
   SetIndexArrow(3,159);
   
   if (!ShowArrows)
   {
      SetIndexStyle(0, DRAW_NONE);
      SetIndexStyle(1, DRAW_NONE);
   }
   
   if (!ShowDots)
   {
      SetIndexStyle(2, DRAW_NONE);
      SetIndexStyle(3, DRAW_NONE);
   }
   
   SetIndexEmptyValue(0, EMPTY_VALUE);
   SetIndexEmptyValue(1, EMPTY_VALUE);
   SetIndexEmptyValue(2, EMPTY_VALUE);
   SetIndexEmptyValue(3, EMPTY_VALUE);
      
   ArraySetAsSeries(BuySignalBuffer, true);
   ArraySetAsSeries(SellSignalBuffer, true);
   ArraySetAsSeries(BuyDotBuffer, true);
   ArraySetAsSeries(SellDotBuffer, true);   
   
   ArrayInitialize(BuySignalBuffer, EMPTY_VALUE);
   ArrayInitialize(SellSignalBuffer, EMPTY_VALUE);
   ArrayInitialize(BuyDotBuffer, true);
   ArrayInitialize(SellDotBuffer, true);   
         
   LastAlertTime = TimeCurrent()-PeriodSeconds();

//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//---
   int limit = rates_total;
   if (prev_calculated > 0) limit = rates_total-prev_calculated;
   if (limit >= rates_total - 2) limit = rates_total - 3;
   
   for (int i=limit; i>0; i--)
   {
      BuySignalBuffer[i] = EMPTY_VALUE;
      SellSignalBuffer[i] = EMPTY_VALUE;
      BuyDotBuffer[i] = EMPTY_VALUE;
      SellDotBuffer[i] = EMPTY_VALUE;
      int lastSignalType = -1;
      double avRange = 0;
      
      if (High[i] > High[i+1] && Close[i] > High[i+1])
      {
         avRange = AvRange(i, high, low, rates_total);
         BuyDotBuffer[i] = Low[i] - avRange / 1.5;
         lastSignalType = GetLastSignalType(i);
         if (lastSignalType != OP_BUY) BuySignalBuffer[i] = Low[i] - avRange;
      }
      if (Low[i] < Low[i+1] && Close[i] < Low[i+1])
      {
         avRange = AvRange(i, high, low, rates_total);
         SellDotBuffer[i] = High[i] + avRange / 1.5;
         lastSignalType = GetLastSignalType(i);
         if (lastSignalType != OP_SELL) SellSignalBuffer[i] = High[i] + avRange;
      }
   }
   
   if (ShowAlert && Time[0] > LastAlertTime)
   {  
      string msg = "";
      if (NormalizeDouble(BuySignalBuffer[1],Digits) != EMPTY_VALUE)
      {
         msg = WindowExpertName()+" BUY signal for "+_Symbol+" on "+EnumToString((ENUM_TIMEFRAMES)_Period)+" at "+TimeToStr(Time[1]);
         Alert(msg);
         LastAlertTime = Time[0];
      }
      else if (NormalizeDouble(SellSignalBuffer[1],Digits) != EMPTY_VALUE)
      {
         msg = WindowExpertName()+" SELL signal for "+_Symbol+" on "+EnumToString((ENUM_TIMEFRAMES)_Period)+" at "+TimeToStr(Time[1]);
         Alert(msg);
         LastAlertTime = Time[0];
      }         
   }
   
//--- return value of prev_calculated for next call
   return(rates_total);
  }
  
double AvRange(int pos, double const &high[], double const &low[], double rates_total)
{
   double sum=0;   
   int count = 4;
   int i=pos;
   
   while (i<rates_total && count > 0)
   {
      sum += high[i]-low[i];
      count--;
      i++;
   }
   return (sum/8);
}

int GetLastSignalType(int startIndex)
{
   int signalType = -1;
   int i = startIndex + 1;
   while (i < Bars && signalType == -1)
   {
      if (BuyDotBuffer[i]!= EMPTY_VALUE)
      {
         signalType = OP_BUY;
      }
      else if (SellDotBuffer[i] != EMPTY_VALUE)
      {
         signalType = OP_SELL;
      }
      i++;
   }
   return (signalType);
}
//+------------------------------------------------------------------+
